@@ -5,8 +5,6 @@ import asyncio
 from lunar.config import Config
 from lunar.lunar_client import LunarClient
 
-LUNAR_DATA_QUERY_API_URL = "/v1/query"
-
 loop = asyncio.get_event_loop()
 
 
@@ -26,8 +24,6 @@ class QueryClient(LunarClient):
     def __init__(self, config: Config):
         super().__init__(config)
 
-        self.api_url = LUNAR_DATA_QUERY_API_URL if config.ENV == "LOCAL" else f"/api{LUNAR_DATA_QUERY_API_URL}"
-
     async def get_query_async(
         self,
         dataset_id: str,
@@ -76,7 +72,7 @@ class QueryClient(LunarClient):
             assert isinstance(limit, int), "`limit` type must be int"
             data["limit"] = limit
 
-        body = await self._request(method="POST", url=self.api_url, data=data, headers=headers)
+        body = await self._request(method="POST", url=self.config.API_PATH, data=data, headers=headers)
 
         return body["data"]
 
