@@ -10,10 +10,11 @@ class LunarError(Exception):
     Exception class for Lunar Client.
     """
 
-    def __init__(self, code: int, msg: str):
+    def __init__(self, code: int, msg: str, error_code: str = ""):
         super().__init__(msg)
         self.code = code
         self.msg = msg
+        self.error_code = error_code
 
 
 class LunarClient:
@@ -22,6 +23,7 @@ class LunarClient:
     """
 
     def __init__(self, config: Config):
+        self.config = config
         self.url = config.URL
         self.env = config.ENV
         self.apikey_header = {"x-api-key": config.APIKEY}
@@ -29,10 +31,12 @@ class LunarClient:
     async def _request(
         self, method: str, url: str, headers: Dict[str, Any] = None, data: Any = None, params=None
     ) -> Any:
+        api_path = url if self.config.ENV == "LOCAL" or self.config.RUNTIME_ENV == "BAP" else f"/api{url}"
+
         async with aiohttp.ClientSession() as session:
             async with session.request(
                 method=method,
-                url=f"{self.url}{'' if url.startswith('/') else '/'}{url}",
+                url=f"{self.url}{'' if api_path.startswith('/') else '/'}{api_path}",
                 headers={**self.apikey_header, **headers} if headers else self.apikey_header,
                 json=data,
                 params=params,
@@ -40,7 +44,7 @@ class LunarClient:
                 try:
                     body = await response.json()
                     if not response.ok:
-                        raise LunarError(code=response.status, msg=body.get("error"))
+                        raise LunarError(code=response.status, msg=body.get("message"), error_code=body.get("code"))
                     return body
                 except aiohttp.client_exceptions.ContentTypeError:
                     return await response.text() or None
