@@ -89,7 +89,8 @@ class EDDService:
         db_type: str,
         operation: str,
         target_name: str = None,
-        partition: str = None,
+        s3_dt: str = None,
+        edd_table_partition: str = None,
     ) -> Dict[str, Any]:
         """
         Copy a table from EDD S3 to Lunar S3 and Database(dynamodb or docdb).
@@ -99,9 +100,10 @@ class EDDService:
         - database_name: (str) Database name of EDD S3 ('Datalake' is not available)
         - table_name: (str) Name of a table on EDD S3
         - db_type: (str) Type of database to be loaded on Lunar ('dynamodb' | 'docdb')
-        - operation: (str) Type of operation ('put' | 'delete')
+        - operation: (str) Type of operation ('put' | 'update' | 'delete')
         - target_name: (optional) (str) Target name on database to be loaded (Default: Value of `table_name`)
-        - partition: (optional) (str) Partition value of table on EDD S3
+        - s3_dt: (optional) (str) Set a dt partition on Lunar S3. If db_type is `docdb`, it is necessary
+        - edd_table_partition: (optional) (str) Partition value of table on EDD S3
 
         ## Returns
         dict
@@ -115,7 +117,8 @@ class EDDService:
             db_type="docdb",
             operation="put",
             target_name="test_data",
-            partition="202109",
+            s3_dt="20211101",
+            edd_table_partition="dt=202109/type=put",
         )
 
 
@@ -123,7 +126,10 @@ class EDDService:
         """
 
         assert db_type in ["dynamodb", "docdb"], "`db_type` must be one of `dynamodb` or `docdb`"
-        assert operation in ["put", "delete"], "`operation` must be one of `put` or `delete`"
+        assert operation in ["put", "update", "delete"], "`operation` must be one of `put` or `update` or `delete`"
+
+        if db_type == "docdb" and not s3_dt:
+            raise LunarError(code=400, msg="Parameter 's3_dt' is necessary when db_type is 'docdb'")
 
         target_name = target_name if target_name else table_name
 
@@ -133,14 +139,17 @@ class EDDService:
         if job_name in job_list:
             raise LunarError(code=400, msg=f"Job {job_name} is already submitted to Lunar S3")
 
+        s3_dt_str = f"dt={s3_dt}/" if s3_dt else ""
+
         data = {
             "database_name": database_name,
             "table_name": table_name,
-            "s3_path": f"s3://lunar-loader-{self.config.ENV.lower()}/{db_type}/{target_name}/op={operation}/",
+            "s3_path": f"s3://lunar-loader-{self.config.ENV.lower()}/{db_type}/{target_name}/{s3_dt_str}op={operation}/",
             "user_id": os.uname()[1].split("-")[2],
         }
-        if partition:
-            data["partition"] = partition
+        if edd_table_partition:
+            data["partition"] = edd_table_partition
+            data["write_raw_s3_path"] = True
 
         response = requests.post(
             url=self.config.COPY_DATABASE_URL,
