@@ -7,8 +7,6 @@ from lunar.config import Config
 from lunar.lunar_client import LunarClient, LunarError
 from lunar.rec.channels.models import Channel, ChannelPutIn, ChannelPatchIn
 
-LUNAR_REC_CHANNELS_API_URL = "/v1/channels"
-
 loop = asyncio.get_event_loop()
 
 
@@ -28,8 +26,6 @@ class ChannelClient(LunarClient):
     def __init__(self, config: Config):
         super().__init__(config)
 
-        self.api_url = LUNAR_REC_CHANNELS_API_URL if config.ENV == "LOCAL" else f"/api{LUNAR_REC_CHANNELS_API_URL}"
-
     async def create_channel_async(self, id: str, experiment_id: str = None) -> Channel:
         """
         Create a new channel (async).
@@ -54,7 +50,7 @@ class ChannelClient(LunarClient):
         except ValidationError as e:
             raise LunarError(code=400, msg=str(e))
 
-        body = await self._request(method="POST", url=self.api_url, data=channel.dict())
+        body = await self._request(method="POST", url=self.config.API_PATH, data=channel.dict())
         return Channel(**body["data"])
 
     def create_channel(self, id: str, experiment_id: str = None) -> Channel:
@@ -93,7 +89,7 @@ class ChannelClient(LunarClient):
         ```
         """
 
-        body = await self._request(method="GET", url=self.api_url)
+        body = await self._request(method="GET", url=self.config.API_PATH)
         return [Channel(**channel) for channel in body["data"]]
 
     def list_channels(self) -> List[Channel]:
@@ -130,7 +126,7 @@ class ChannelClient(LunarClient):
         ```
         """
 
-        body = await self._request(method="GET", url=f"{self.api_url}/{id}")
+        body = await self._request(method="GET", url=f"{self.config.API_PATH}/{id}")
         return Channel(**body["data"])
 
     def get_channel(self, id: str) -> Channel:
@@ -177,7 +173,7 @@ class ChannelClient(LunarClient):
         except ValidationError as e:
             raise LunarError(code=400, msg=str(e))
 
-        body = await self._request(method="PUT", url=f"{self.api_url}/{id}", data=updated_channel.dict())
+        body = await self._request(method="PUT", url=f"{self.config.API_PATH}/{id}", data=updated_channel.dict())
         return Channel(**body["data"])
 
     def update_channel(self, id: str, experiment_id: str = None) -> Channel:
@@ -224,7 +220,7 @@ class ChannelClient(LunarClient):
         patched_channel = ChannelPatchIn(**{"experiment_id": experiment_id})
 
         body = await self._request(
-            method="PATCH", url=f"{self.api_url}/{id}", data=patched_channel.dict(exclude_none=True)
+            method="PATCH", url=f"{self.config.API_PATH}/{id}", data=patched_channel.dict(exclude_none=True)
         )
         return Channel(**body["data"])
 
@@ -265,7 +261,7 @@ class ChannelClient(LunarClient):
         ```
         """
 
-        return await self._request(method="DELETE", url=f"{self.api_url}/{id}")
+        return await self._request(method="DELETE", url=f"{self.config.API_PATH}/{id}")
 
     def delete_channel(self, id: str) -> None:
         """
